@@ -2,6 +2,10 @@ pub fn add(a: u32, b: u32) -> u32 {
     a + b
 }
 
+pub fn super_function() -> &'static str {
+    "SUPER VALUE"
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
